@@ -67,8 +67,9 @@
 #' @param data_geom Geom \code{function} or \code{list} of geom functions used
 #'   for plotting data in background. The default (missing) uses
 #'   \code{\link[ggplot2]{geom_point}} if \code{trace} is specified, otherwise
-#'   \code{\link[ggbeeswarm]{geom_beeswarm}} (a good alternative is
-#'   \code{ggbeeswarm::geom_quasirandom}) . See examples fo further options.
+#'   \code{\link[ggbeeswarm]{geom_beeswarm}} (a good alternative in case of many
+#'   data points is \code{ggbeeswarm::geom_quasirandom}) . See examples fo
+#'   further options.
 #' @param data_alpha numeric \code{alpha} value between 0 and 1 passed to
 #'   \code{data_geom}. Default is \code{0.5} which correspond to semitransparent
 #'   data points in the background such that overlapping data points are plotted
@@ -107,6 +108,10 @@
 #'   emits a \code{message} with \code{old -> new} factor levels.
 #' @param legend_title A scalar \code{character} vector with a new title for the
 #'   legend.
+#' @param plot_first A \code{ggplot2} geom (or a list of geoms) that will be
+#'   added to the returned plot as a first element (i.e., before any of the
+#'   other graphical elements). Useful for adding reference lines or similar
+#'   (e.g., using \code{\link[ggplot2]{geom_hline}}).
 #' @param data For the \code{afex_plot.default} method, an optional
 #'   \code{data.frame} containing the raw data used for fitting the model and
 #'   which will be used as basis for the data points in the background. If
@@ -117,7 +122,7 @@
 #' @param within_vars,between_vars For the \code{afex_plot.default} method, an
 #'   optional \code{character} vector specifying which variables should be
 #'   treated as within-subjects (or repeated-measures) factors and which as
-#'   between-subjects (or independen-sampels) factors. If one of the two
+#'   between-subjects (or independent-samples) factors. If one of the two
 #'   arguments is given, all other factors are assumed to fall into the other
 #'   category.
 #' @param means \code{data.frame}s used for plotting of the plotting
@@ -306,6 +311,7 @@ afex_plot.afex_aov <- function(object,
                                dodge = 0.5,
                                return = "plot",
                                factor_levels = list(),
+                               plot_first = NULL,
                                legend_title,
                                ...) {
   
@@ -403,6 +409,7 @@ afex_plot.afex_aov <- function(object,
                             line_arg = line_arg,
                             mapping = mapping,
                             legend_title =  legend_title,
+                            plot_first = plot_first,
                             return = return
   ))
 }
@@ -433,6 +440,7 @@ afex_plot.mixed <- function(object,
                             dodge = 0.5,
                             return = "plot",
                             factor_levels = list(),
+                            plot_first = NULL,
                             legend_title,
                             ...) {
   
@@ -536,6 +544,7 @@ afex_plot.mixed <- function(object,
                             line_arg = line_arg,
                             mapping = mapping,
                             legend_title =  legend_title,
+                            plot_first = plot_first,
                             return = return
   ))
 }
@@ -565,6 +574,7 @@ afex_plot.merMod <- function(object,
                             dodge = 0.5,
                             return = "plot",
                             factor_levels = list(),
+                            plot_first = NULL,
                             legend_title,
                             ...) {
   
@@ -667,6 +677,7 @@ afex_plot.merMod <- function(object,
                             line_arg = line_arg,
                             mapping = mapping,
                             legend_title =  legend_title,
+                            plot_first = plot_first,
                             return = return
   ))
 }
@@ -698,6 +709,7 @@ afex_plot.default <- function(object,
                               dodge = 0.5,
                               return = "plot",
                               factor_levels = list(),
+                              plot_first = NULL,
                               legend_title,
                               ...) {
   
@@ -828,6 +840,7 @@ afex_plot.default <- function(object,
                             line_arg = line_arg,
                             mapping = mapping,
                             legend_title =  legend_title,
+                            plot_first = plot_first,
                             return = return
   ))
 }
