@@ -1,5 +1,3 @@
-context("afex_plot vignette: saved objects replicate")
-
 test_that("glmmTMB object", {
   testthat::skip_if_not_installed("emmeans")
   testthat::skip_if_not_installed("ggplot2")
@@ -13,7 +11,7 @@ test_that("glmmTMB object", {
   # tmb <- tmb2
   # save(tmb, file = "inst/extdata/tmb_example_fit.rda", 
   #      compress = "xz")
-  load(system.file("extdata/", "tmb_example_fit.rda", package = "afex"))
+  #load(system.file("extdata/", "tmb_example_fit.rda", package = "afex"))
   ## previous versions checked for equivalence of summary() or coef(), but that
   ## seems unnecessary and did fail at some point 
   ## (i.e., summary() on old glmmTMB object failed)
@@ -25,18 +23,12 @@ test_that("glmmTMB object", {
   skip_if_not_installed("ggplot2")
   library("ggplot2")
   
-  p1o <- afex_plot(tmb, "spp")
   p1n <- afex_plot(tmb2, "spp")
-  expect_equivalent(p1o, p1n, check.environment = FALSE)
-  
-  p2o <- afex_plot(tmb, "spp", data_geom = geom_violin)
   p2n <- afex_plot(tmb2, "spp", data_geom = geom_violin)
-  expect_equivalent(p2o, p2n, check.environment = FALSE)
-  
-  p3o <- afex_plot(tmb, "spp", id = "site", data = Salamanders)
   p3n <- afex_plot(tmb2, "spp", id = "site", data = Salamanders)
-  expect_equivalent(p3o, p3n, check.environment = FALSE)
-  
+  expect_doppelganger("afex_plot: glmmTMB 1", p1n)
+  expect_doppelganger("afex_plot: glmmTMB 2", p2n)
+  expect_doppelganger("afex_plot: glmmTMB 3", p3n)
 })
 
 
@@ -44,22 +36,27 @@ test_that("rstanarm plots", {
   testthat::skip_if_not_installed("emmeans")
   testthat::skip_if_not_installed("ggplot2")
   skip_on_cran()
+  #skip_on_ci()
   skip_if_not_installed("rstanarm")
   library("rstanarm") ## requires resetting the ggplot2 theme
   skip_if_not_installed("ggplot2")
   library("ggplot2")
   set_sum_contrasts()
+  load("afex_plot-rstanarm.rda") ## comparison values
+  
+  tol <- 0.1
+  
   cbpp <- lme4::cbpp 
   cbpp$prob <- with(cbpp, incidence / size)
   suppressWarnings(capture_output({
   example_model <- rstanarm::stan_glmer(prob ~ period + (1|herd),
                                         data = cbpp, family = binomial, weight = size,
-                                        chains = 2, cores = 1, seed = 12345, iter = 500)
+                                        chains = 2, cores = 1, seed = 12345, 
+                                        iter = 1000, warmup = 500)
   }))
-  b1n <- afex_plot(example_model, "period")
-  b2n <- afex_plot(example_model, "period", data_geom = geom_violin)
-  expect_is(b1n, "ggplot")
-  expect_is(b2n, "ggplot")
+  
+  b1d <- afex_plot(example_model, "period", return = "data")
+  expect_equal(b1d, rstanenv$b1d, tolerance = tol)
   
   ## make cbpp long
   cbpp_l <- vector("list", nrow(cbpp))
@@ -79,40 +76,43 @@ test_that("rstanarm plots", {
     example_model2 <- rstanarm::stan_glmer(incidence ~ period + (1|herd),
                                            data = cbpp_l, family = binomial, 
                                            chains = 2, cores = 1, seed = 12345, 
-                                           iter = 500)
+                                           iter = 1000)
   }))
   
-  b3n <- afex_plot(example_model2, "period")
-  b4n <- afex_plot(example_model2, "period", id = "herd")
-  # b3n <- afex_plot(example_model2, "period", id = "herd", data = cbpp_l)
-  expect_is(b3n, "ggplot")
-  expect_is(b4n, "ggplot")
+  b3d <- afex_plot(example_model2, "period", return = "data")
+  b4d <- afex_plot(example_model2, "period", id = "herd", return = "data")
+  expect_equal(b3d, rstanenv$b3d, tolerance = tol)
+  expect_equal(b4d, rstanenv$b4d, tolerance = tol)
   
   skip_if_not_installed("MEMSS")
   data("Machines", package = "MEMSS") 
   
   suppressWarnings(capture_output({
     mm <- rstanarm::stan_lmer(score ~ Machine + (Machine|Worker), data=Machines,
-                            chains = 2, cores = 1, seed = 12345, iter = 500)
+                            chains = 2, cores = 1, seed = 12345, iter = 1000)
   }))
   
-  b5n <- afex_plot(mm, "Machine")
-  b6n <- afex_plot(mm, "Machine", id = "Worker")
-  load(system.file("extdata/", "plots_rstanarm.rda", package = "afex"))
+  b5d <- afex_plot(mm, "Machine", return = "data")
+  b6d <- afex_plot(mm, "Machine", id = "Worker", return = "data")
+  expect_equal(b5d, rstanenv$b5d, tolerance = tol)
+  expect_equal(b6d, rstanenv$b6d, tolerance = tol)
   
-  expect_equivalent(b1$data, b1n$data, tolerance = 0.1)
-  expect_equivalent(b2$data, b2n$data, tolerance = 0.1)
-  expect_equivalent(b3$data, b3n$data, tolerance = 0.1)
-  expect_equivalent(b4$data, b4n$data, tolerance = 0.1)
-  expect_equivalent(b5$data, b5n$data, tolerance = 0.1)
-  expect_equivalent(b6$data, b6n$data, tolerance = 0.1)
+  #### save
+  # rstanenv <- new.env()
+  # rstanenv$b1d <- b1d
+  # rstanenv$b3d <- b3d
+  # rstanenv$b4d <- b4d
+  # rstanenv$b5d <- b5d
+  # rstanenv$b6d <- b6d
+  # ls(envir = rstanenv)
+  # save(rstanenv, file = "tests/testthat/afex_plot-rstanarm.rda")
 })
 
 test_that("brms plots", {
   testthat::skip_if_not_installed("emmeans")
   testthat::skip_if_not_installed("ggplot2")
   skip_on_cran()
-  skip_on_travis()
+  #skip_on_os("windows")
   skip_if_not_installed("brms")
   library("brms") ## requires resetting the ggplot2 theme
   skip_if_not_installed("ggplot2")
@@ -122,15 +122,20 @@ test_that("brms plots", {
   data("Machines", package = "MEMSS") 
   suppressWarnings(capture_output({
     mm2 <- brm(score ~ Machine + (Machine|Worker), data=Machines, 
-               chains = 2, cores = 1, seed = 12345, iter = 500)
+               chains = 2, cores = 1, seed = 12345, iter = 1000)
   }))
-  bb1n <- afex_plot(mm2, "Machine", data = Machines, dv = "score")
+  bb1n <- afex_plot(mm2, "Machine", data = Machines, dv = "score", 
+                    return = "data")
   bb2n <- afex_plot(mm2, "Machine", id = "Worker", 
-                   data = Machines, dv = "score")
-  load(system.file("extdata/", "plots_brms.rda", package = "afex"))
-  
-  expect_equivalent(bb1$data, bb1n$data, tolerance = 0.1)
-  expect_equivalent(bb2$data, bb2n$data, tolerance = 0.1)
+                   data = Machines, dv = "score", return = "data")
+  load("afex_plot-brms.rda")
+  expect_equal(bb1n, brmslist$bb1n, tolerance = 5)
+  expect_equal(bb2n, brmslist$bb2n, tolerance = 5)
+  # brmslist <- list(
+  #   bb1n = bb1n,
+  #   bb2n = bb2n
+  # )
+  # save(brmslist, file = "tests/testthat/afex_plot-brms.rda")
   
   expect_error(afex_plot(mm2, "Machine", data = Machines), 
                "Could not detect dv column")
